@@ -1,5 +1,5 @@
 package App::Sky::CmdLine;
-$App::Sky::CmdLine::VERSION = '0.4.0';
+$App::Sky::CmdLine::VERSION = '0.4.1';
 use strict;
 use warnings;
 
@@ -106,8 +106,7 @@ sub run
 
         if ($copy)
         {
-            require Clipboard;
-            Clipboard->VERSION('0.19');
+            eval "use Clipboard 0.19;";
             Clipboard->copy_to_all_selections($URL);
         }
 
@@ -170,7 +169,7 @@ App::Sky::CmdLine
 
 =head1 VERSION
 
-version 0.4.0
+version 0.4.1
 
 =head1 NAME
 
@@ -178,7 +177,7 @@ App::Sky::CmdLine - command line program
 
 =head1 VERSION
 
-version 0.4.0
+version 0.4.1
 
 =head1 METHODS
 
